@@ -133,7 +133,8 @@ char *fname;
 	prop.type = RENDERT_SMART;
 
 	if (info->fullwin)
-		set_root_bg_real(&info->fullwin, img, &prop, NULL, 0, 0, FALSE);
+		set_root_bg_real(&info->fullwin, img, fname, 
+				 &prop, NULL, 0, 0, FALSE);
 
 	absimg_destroy(img);
 	gdk_flush();
@@ -678,7 +679,8 @@ rendering_type type;
 
 	prop.type = type;
 
-	set_root_bg_real(&info->root_window, image, &prop, NULL, 0, 0, TRUE);
+	set_root_bg_real(&info->root_window, image, pe->name, 
+			 &prop, NULL, 0, 0, TRUE);
 
 	gdk_flush();
 	chbg_status_progress(0,1);
